@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2015-02-18'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -251,10 +251,10 @@ sub known_settings {
                 schema  => 'str*',
             },
         };
-        require Data::Sah;
+        require Data::Sah::Normalize;
         for (keys %$settings) {
             for ($settings->{$_}{schema}) {
-                $_ = Data::Sah::normalize_schema($_);
+                $_ = Data::Sah::Normalize::normalize_schema($_);
             }
         }
     }
@@ -740,7 +740,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
